(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23395,        865]*)
(*NotebookOutlinePosition[     24377,        897]*)
(*  CellTagsIndexPosition[     24333,        893]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData[All, "Working"],
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  ScriptMinSize->12,
  FontSize->18],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  ScriptMinSize->8],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  StyleMenuListing->None,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellFrame->{{0, 0}, {5, 0}},
  CellMargins->{{72, Inherited}, {20, 20}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0, 0.4, 0.6],
  TextAlignment->Left,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Times",
  FontSize->50,
  FontWeight->"Plain",
  Background->GrayLevel[1]],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{24, Inherited}, {60, Inherited}},
  LineSpacing->{1, 0},
  FontColor->RGBColor[1, 1, 0]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{54, Inherited}, {20, Inherited}},
  CellFrameColor->GrayLevel[0.8],
  FontFamily->"B Frutiger Bold",
  FontSize->24],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{54, Inherited}, {10, 30}},
  CellElementSpacings->{"CellMinHeight"->12},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CellFrameMargins->2,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->RGBColor[0, 0.4, 0.6],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{24, Inherited}, {6, Inherited}},
  LineSpacing->{1, 0},
  FontSize->30],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{54, Inherited}, {6, Inherited}},
  FontSize->18,
  Background->GrayLevel[0.500008]],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{72, Inherited}, {40, Inherited}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  TextAlignment->Left,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{24, Inherited}, {6, Inherited}},
  LineSpacing->{1, 0},
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{54, Inherited}, {20, Inherited}},
  FontFamily->"I Frutiger Italic",
  FontSize->12],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {2, 0}},
  CellDingbat->"\[GraySquare]",
  CellMargins->{{72, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0, 0.4, 0.6],
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{24, Inherited}, {Inherited, 20}},
  LineSpacing->{1, 0},
  FontSize->24,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{72, Inherited}, {Inherited, 20}},
  CellFrameColor->GrayLevel[0],
  FontFamily->"B Frutiger Bold",
  FontSize->16],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{81, Inherited}, {Inherited, 18}},
  CellElementSpacings->{"ClosedCellHeight"->30},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.4, 0.6]],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{24, Inherited}, {Inherited, 15}},
  LineSpacing->{1, 0},
  FontSize->24,
  FontColor->RGBColor[0, 1, 0]],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, 15}},
  FontFamily->"B Frutiger Bold",
  FontSize->14,
  FontColor->GrayLevel[0]],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[EmptySquare]",
  CellMargins->{{81, Inherited}, {Inherited, 12}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{36, Inherited}, {Inherited, 12}},
  LineSpacing->{1, 0},
  FontSize->18,
  FontColor->RGBColor[0, 0.869993, 0]],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, 12}},
  FontFamily->"BI Frutiger BoldItalic",
  FontSize->12],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  TextJustification->0.75,
  FontFamily->"Times New Roman",
  FontSize->12],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{24, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0},
  FontSize->20,
  FontColor->GrayLevel[1]],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  TextJustification->1,
  FontFamily->"Sabon",
  FontSize->12],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{24, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->14],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, Inherited}},
  FontSize->9],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->9]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->True,
  CellMargins->{{117, Inherited}, {5, 10}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameLabelMargins->8,
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->GrayLevel[0.900008]],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{45, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0},
  FontSize->20,
  FontColor->RGBColor[1, 1, 0],
  Background->RGBColor[0, 0, 0.8]],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{90, 20}, {5, 10}},
  FontSize->10],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellFrame->False,
  CellMargins->{{117, Inherited}, {10, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{45, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0},
  FontSize->20,
  FontColor->GrayLevel[1]],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{90, Inherited}, {15, Inherited}},
  FontSize->10],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{117, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{117, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Info"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Info", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Info", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Info", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Graphics", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->14],

Cell[StyleData["CellLabel", "Printout"],
  FontSize->8,
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->8]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{72, 20}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  TextAlignment->-0.5,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontFamily->"Times New Roman",
  FontSize->12],

Cell[StyleData["NumberedEquation", "Presentation"],
  CellMargins->{{18, 3}, {15, Inherited}},
  ShowCellLabel->False,
  CellFrameLabels->{{Inherited, None}, {Inherited, Inherited}},
  CellFrameLabelMargins->False,
  TextAlignment->-0.5,
  LineSpacing->{1, 0},
  FontSize->24,
  FontColor->RGBColor[0, 1, 0]],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{72, 20}, {Inherited, Inherited}},
  FontFamily->"Sabon"],

Cell[StyleData["NumberedEquation", "Condensed"],
  CellMargins->{{72, 72}, {Inherited, Inherited}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{72, Inherited}, {20, 10}},
  CellFrameLabels->{{Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"], ". "}]], None}, {None, None}},
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False,
  FontFamily->"Times",
  FontSize->14],

Cell[StyleData["NumberedFigure", "Presentation"],
  CellMargins->{{24, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0},
  FontSize->18,
  FontColor->RGBColor[0, 1, 0]],

Cell[StyleData["NumberedFigure", "Printout"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  FontFamily->"I Frutiger Italic",
  FontSize->10],

Cell[StyleData["NumberedFigure", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}]], None}},
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedTable", "Presentation"],
  CellMargins->{{24, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedTable", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["NumberedTable", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Header"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["LeftHeader"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["Footer"],
  TextAlignment->Center,
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["LeftFooter"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell["\<\
The \"RefGuide\" style is for linking automatically to the on-line \
Reference Guide help system.\
\>", "Text"],

Cell[StyleData["RefGuide"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ #]}]&),
  Active->True}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None,
  DrawHighlighted->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{1, -5},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  CellMargins->{{0, 0}, {0, 0}},
  TextAlignment->Left,
  ScriptLevel->1,
  ImageMargins->{{0, 0}, {0, 0}},
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowToolbars->"RulerBar",
WindowSize->{503, 327},
WindowMargins->{{Automatic, 1}, {Automatic, 8}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True,
"FirstPageFace"->Right},
Background->GrayLevel[1],
MacintoshSystemPageSetup->"\<\
00l0001804P000000_P2B?ofoo833P9F;085:0?l0@00005X0FP000003]P;J001
0@00I00100000@0200000BL?00400000000000000000030001000000000@0?o>
okX?AP^^0201000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 64, "Subtitle"],
Cell[1771, 53, 193, 5, 76, "Text"],

Cell[CellGroupData[{
Cell[1989, 62, 74, 1, 60, "Section"],
Cell[2066, 65, 51, 1, 36, 31, 0, "StyleData", "All", "Working"],
Cell[2120, 68, 73, 2, 42, 36, 0, "StyleData", "All", "Presentation"],
Cell[2196, 72, 164, 4, 36, 33, 0, "StyleData", "All", "Condensed"],
Cell[2363, 78, 104, 2, 36, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2504, 85, 67, 1, 44, "Section"],
Cell[2574, 88, 101, 3, 42, "Text"],
Cell[2678, 93, 81, 2, 36, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[2796, 100, 70, 1, 44, "Section"],

Cell[CellGroupData[{
Cell[2891, 105, 393, 11, 119, 24, 0, "StyleData", "Title", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[3287, 118, 146, 3, 159, 40, 0, "StyleData", "Title", "Presentation"],
Cell[3436, 123, 170, 4, 95, 36, 0, "StyleData", "Title", "Printout"],
Cell[3609, 129, 94, 2, 57, 37, 0, "StyleData", "Title", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[3740, 136, 537, 16, 52, 27, 0, "StyleData", "Subtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4280, 154, 132, 3, 86, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[4415, 159, 140, 3, 74, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[4558, 164, 97, 2, 42, 40, 0, "StyleData", "Subtitle", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[4692, 171, 311, 8, 75, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5006, 181, 167, 4, 44, 46, 0, "StyleData", "Subsubtitle", 
"Presentation"],
Cell[5176, 187, 144, 3, 53, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[5323, 192, 100, 2, 35, 43, 0, "StyleData", "Subsubtitle", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[5460, 199, 403, 11, 58, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[5866, 212, 164, 4, 81, 42, 0, "StyleData", "Section", "Presentation"],
Cell[6033, 218, 170, 4, 74, 38, 0, "StyleData", "Section", "Printout"],
Cell[6206, 224, 96, 2, 44, 39, 0, "StyleData", "Section", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[6339, 231, 412, 11, 40, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[6754, 244, 167, 4, 60, 45, 0, "StyleData", "Subsection", "Presentation"],

Cell[6924, 250, 168, 4, 51, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[7095, 256, 99, 2, 33, 42, 0, "StyleData", "Subsection", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[7231, 263, 286, 8, 38, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[7520, 273, 177, 4, 50, 48, 0, "StyleData", "Subsubsection", 
"Presentation"],
Cell[7700, 279, 151, 3, 45, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[7854, 284, 102, 2, 30, 45, 0, "StyleData", "Subsubsection", "Condensed"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8005, 292, 71, 1, 44, "Section"],

Cell[CellGroupData[{
Cell[8101, 297, 157, 4, 39, 23, 0, "StyleData", "Text", "All"],
Cell[8261, 303, 156, 4, 62, 39, 0, "StyleData", "Text", "Presentation"],
Cell[8420, 309, 156, 4, 37, 35, 0, "StyleData", "Text", "Printout"],
Cell[8579, 315, 93, 2, 32, 36, 0, "StyleData", "Text", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8709, 322, 128, 3, 35, 28, 0, "StyleData", "SmallText", "All"],
Cell[8840, 327, 141, 3, 38, 44, 0, "StyleData", "SmallText", "Presentation"],
Cell[8984, 332, 113, 2, 34, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[9100, 336, 97, 2, 30, 41, 0, "StyleData", "SmallText", "Condensed"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9246, 344, 74, 1, 44, "Section"],
Cell[9323, 347, 248, 5, 76, "Text"],

Cell[CellGroupData[{
Cell[9596, 356, 528, 16, 60, 24, 0, "StyleData", "Input", "All"],
Cell[10127, 374, 197, 5, 82, 40, 0, "StyleData", "Input", "Presentation"],
Cell[10327, 381, 88, 2, 57, 36, 0, "StyleData", "Input", "Printout"],
Cell[10418, 385, 94, 2, 46, 37, 0, "StyleData", "Input", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[10549, 392, 452, 13, 42, 25, 0, "StyleData", "Output", "All"],
Cell[11004, 407, 158, 4, 61, 41, 0, "StyleData", "Output", "Presentation"],
Cell[11165, 413, 104, 2, 47, 37, 0, "StyleData", "Output", "Printout"],
Cell[11272, 417, 95, 2, 31, 38, 0, "StyleData", "Output", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[11404, 424, 447, 12, 36, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[11854, 438, 139, 3, 40, 42, 0, "StyleData", "Message", "Presentation"],
Cell[11996, 443, 139, 3, 35, 38, 0, "StyleData", "Message", "Printout"],
Cell[12138, 448, 96, 2, 31, 39, 0, "StyleData", "Message", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[12271, 455, 446, 12, 36, 24, 0, "StyleData", "Print", "All",
  StyleMenuListing->None],
Cell[12720, 469, 121, 2, 36, 40, 0, "StyleData", "Print", "Presentation"],
Cell[12844, 473, 110, 2, 35, 36, 0, "StyleData", "Print", "Printout"],
Cell[12957, 477, 94, 2, 31, 37, 0, "StyleData", "Print", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[13088, 484, 444, 12, 36, 23, 0, "StyleData", "Info", "All",
  StyleMenuListing->None],
Cell[13535, 498, 120, 2, 36, 39, 0, "StyleData", "Info", "Presentation"],
Cell[13658, 502, 109, 2, 35, 35, 0, "StyleData", "Info", "Printout"],
Cell[13770, 506, 93, 2, 31, 36, 0, "StyleData", "Info", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[13900, 513, 407, 11, 36, 27, 0, "StyleData", "Graphics", "All",
  StyleMenuListing->None],
Cell[14310, 526, 124, 2, 36, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[14437, 530, 113, 2, 35, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[14553, 534, 97, 2, 31, 40, 0, "StyleData", "Graphics", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14687, 541, 128, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[14818, 547, 60, 1, 38, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[14881, 550, 82, 2, 32, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[14966, 554, 56, 1, 32, 41, 0, "StyleData", "CellLabel", "Condensed"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15071, 561, 81, 1, 44, "Section"],
Cell[15155, 564, 225, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[15405, 572, 406, 10, 39, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[15814, 584, 308, 8, 61, 51, 0, "StyleData", "NumberedEquation", 
"Presentation"],
Cell[16125, 594, 121, 2, 37, 47, 0, "StyleData", "NumberedEquation", 
"Printout"],
Cell[16249, 598, 115, 2, 36, 48, 0, "StyleData", "NumberedEquation", 
"Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[16401, 605, 322, 8, 55, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[16726, 615, 171, 4, 64, 49, 0, "StyleData", "NumberedFigure", 
"Presentation"],
Cell[16900, 621, 154, 3, 57, 45, 0, "StyleData", "NumberedFigure", 
"Printout"],
Cell[17057, 626, 103, 2, 31, 46, 0, "StyleData", "NumberedFigure", 
"Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17197, 633, 309, 7, 53, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[17509, 642, 122, 2, 67, 48, 0, "StyleData", "NumberedTable", 
"Presentation"],
Cell[17634, 646, 118, 2, 51, 44, 0, "StyleData", "NumberedTable", "Printout"],

Cell[17755, 650, 102, 2, 47, 45, 0, "StyleData", "NumberedTable", "Condensed"]

}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17906, 658, 81, 1, 60, "Section"],
Cell[17990, 661, 90, 3, 36, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[18083, 666, 94, 3, 36, 29, 0, "StyleData", "LeftHeader", "All",
  StyleMenuListing->None],
Cell[18180, 671, 115, 4, 36, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[18298, 677, 94, 3, 36, 29, 0, "StyleData", "LeftFooter", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[18429, 685, 65, 1, 44, "Section"],
Cell[18497, 688, 121, 3, 42, "Text"],
Cell[18621, 693, 226, 5, 36, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[18850, 700, 295, 7, 36, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19148, 709, 400, 9, 36, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19551, 720, 387, 9, 36, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19941, 731, 401, 9, 36, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[20379, 745, 67, 1, 44, "Section"],
Cell[20449, 748, 184, 4, 59, "Text"],
Cell[20636, 754, 302, 8, 36, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[20941, 764, 121, 3, 42, "Text"],
Cell[21065, 769, 277, 7, 36, 27, 0, "StyleData", "RefGuide", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[21379, 781, 69, 1, 44, "Section"],
Cell[21451, 784, 115, 3, 42, "Text"],
Cell[21569, 789, 145, 5, 36, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[21717, 796, 179, 6, 36, 39, 0, "StyleData", "SelectionPlaceholder", 
"All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[21933, 807, 68, 1, 44, "Section"],
Cell[22004, 810, 258, 5, 76, "Text"],
Cell[22265, 817, 263, 8, 36, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[22531, 827, 106, 3, 36, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[22640, 832, 150, 5, 37, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[22793, 839, 108, 3, 36, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[22904, 844, 179, 5, 36, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[23086, 851, 115, 3, 42, "Text"],
Cell[23204, 856, 163, 5, 28, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

